@@ -64,10 +64,11 @@ def version():
 @cli.command()
 @click.option("--yes", is_flag=True, help="Automatically answer 'yes' to setup prompts")
 @click.option("--teacher", is_flag=True, help="Install in teacher mode")
+@click.option("--config", help="Path to config file (default: ~/.mwc)")
 @click.pass_context
-def setup(ctx, yes, teacher):
+def setup(ctx, yes, teacher, config):
     """Set up the MWC command line interface"""
-    settings = read_settings()
+    settings = read_settings(config)
     rc_tasks = []
     click.echo(address(INTRO_MESSAGE))
     for note in INTRO_NOTES:
@@ -118,15 +119,16 @@ def setup(ctx, yes, teacher):
     
     ctx.invoke(update)
 
-def get_course_by_name(name, courses);
+def get_course_by_name(name, courses):
     for course in courses:
         if course['name'] == name:
             return course
 
 @cli.command()
-def update():
+@click.option("--config", help="Path to config file (default: ~/.mwc)")
+def update(config):
     """Update the MWC work directory"""
-    settings = read_settings()
+    settings = read_settings(config)
     curr = get_curriculum(settings)
     course = [c for c in curr['courses'] if c['name'] == settings['course']][0]
     backend = course['git_backend']
