@@ -4,16 +4,20 @@ import os
 
 # The default location for the MWC configuration file is ~/.mwc.
 # This can be specified (e.g. to support parallel installations) using
-# the MWC_CONFIG environment variable.
-if "MWC_CONFIG" in os.environ:
-    settings_path = Path(os.environ["MWC_CONFIG"])
-else:
-    settings_path = Path.home() / ".mwc"
+# the MWC_CONFIG environment variable or the --config flag.
 
-def read_settings():
+def read_settings(settings_path=None):
     """Reads the settings file and returns a dict. 
     If the settings file does not exist, returns {}
     """
+    if settings_path:
+        settings_path = Path(settings_path)
+    else:
+        if "MWC_CONFIG" in os.environ:
+            settings_path = Path(os.environ["MWC_CONFIG"])
+        else:
+            settings_path = Path.home() / ".mwc"
+
     if settings_path.exists():
         return yaml.safe_load(settings_path.read_text())
     else:
